@@ -1,12 +1,14 @@
 import os
 from shutil import copyfile
 
+from ..checks.issues import Issues
 from .utils import create_parent_directory
 
 
 class File:
     def __init__(self, path, content_directory):
         self.path = path
+        self.references = []
         self.content_directory = content_directory
         self.content_relative_path = os.path.relpath(
             self.path, self.content_directory.path
@@ -29,3 +31,18 @@ class File:
             os.remove(target_path)
 
         copyfile(self.path, target_path)
+
+    def check_output(self):
+        issues = Issues()
+
+        for check in self.get_checks():
+            for issue in check.run():
+                issues.append(issue)
+
+        if issues:
+            issues.print(f"Issues in {self.content_relative_path}")
+
+        return issues
+
+    def get_checks(self):
+        return []
